@@ -30,21 +30,23 @@ async def addme(a: int, b: int) -> int:
         """Get a personalized greeting"""
         return f"Hello, {name}!"
     
-    options = mcp.create_initialization_options()
-    async with stdio_server() as (read_stream, write_stream):
-        await mcp.run(read_stream, write_stream, options)
+    # options = mcp.create_initialization_options()
+    # async with stdio_server() as (read_stream, write_stream):
+    #     await mcp.run(read_stream, write_stream, options)
+    mcp.run()
 
 
 
 if __name__ == "__main__":
-    import argparse
-    import asyncio
+    # import argparse
+    # import asyncio
 
-    parser = argparse.ArgumentParser(
-            description="give a model the ability to handle time queries and timezone conversions"
-        )
-    parser.add_argument("--local-timezone", type=str, help="Override local timezone")
+    # parser = argparse.ArgumentParser(
+    #         description="give a model the ability to handle time queries and timezone conversions"
+    #     )
+    # parser.add_argument("--local-timezone", type=str, help="Override local timezone")
 
-    args = parser.parse_args()
-    asyncio.run(addme(args.local_timezone))
+    # args = parser.parse_args()
+    # asyncio.run(addme(args.local_timezone))
+    addme()
  
\ No newline at end of file
